# pysesame3

_Unofficial Python Library to communicate with SESAME 3 series products from CANDY HOUSE, Inc._

[![PyPI](https://img.shields.io/pypi/v/pysesame3)](https://pypi.python.org/pypi/pysesame3)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pysesame3)
![GitHub Workflow Status (branch)](https://img.shields.io/github/workflow/status/mochipon/pysesame3/dev%20workflow/main)
[![Documentation Status](https://readthedocs.org/projects/pysesame3/badge/?version=latest)](https://pysesame3.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/mochipon/pysesame3/branch/main/graph/badge.svg?token=2Y7OPZTILT)](https://codecov.io/gh/mochipon/pysesame3)
![PyPI - License](https://img.shields.io/pypi/l/pysesame3)

This project aims to control SESAME 3 series devices by using **[the cloud service](https://doc.candyhouse.co/ja/flow_charts#candy-house-cloud-%E3%81%A8-wifi-module-%E7%B5%8C%E7%94%B1%E3%81%A7-sesame-%E3%82%92%E9%81%A0%E9%9A%94%E6%93%8D%E4%BD%9C)**.
If you want to control them directly via **Bluetooth connection**, please check [pysesameos2](https://github.com/mochipon/pysesameos2).

* Free software: MIT license
* Documentation: [https://pysesame3.readthedocs.io](https://pysesame3.readthedocs.io)

## Features

Please note that `pysesame3` can only control [SESAME 3 Smart Lock](https://jp.candyhouse.co/products/sesame3) at this moment. It could technically support [SESAME Bot](https://jp.candyhouse.co/collections/frontpage/products/sesame3-bot) as well, but I don't have that device. PRs are always welcome!

* Retrieve status of a SESAME lock (locked, handle position, etc.).
* Retrieve recent events (locked, unlocked, etc.) associated with a lock.
* Needless to say, locking and unlocking!

## Usage

Please take a look at [the documentation](https://pysesame3.readthedocs.io/en/latest/usage/).

## Credits & Thanks

* A huge thank you to all at [CANDY HOUSE](https://jp.candyhouse.co/) and their crowdfunding contributors!
* This project was inspired and based on [tchellomello/python-ring-doorbell](https://github.com/tchellomello/python-ring-doorbell) and [snjoetw/py-august](https://github.com/snjoetw/py-august).
